Feedforward Closedloop Learning: Bandpass Class Reference

Feedforward Closedloop Learning

Public Member Functions | List of all members
Bandpass Class Reference

Creates memory traces at specified length. More...

`#include <bandpass.h>`

## Public Member Functions
| Bandpass ()
| Constructor.
double | filter (double v)
| Filter.
void | calcPolesZeros (double f, double r)
| Calculates the coefficients The frequency is the normalized frequency in the range [0..0.5].
void | setParameters (double frequency, double Qfactor)
| sets the filter parameters
void | impulse (char *name)
| Generates an acsii file with the impulse response of the filter.
void | calcNorm (double f)
| Normalises the output with f.
void | transfer (char *name)
| Generates an ASCII file with the transfer function.
double | getOutput ()
| Gets the output of the filter. More...
void | reset ()
| Sets the output to zero again.

## Detailed Description

Creates memory traces at specified length.

It's a 2nd order IIR filter.

## Member Function Documentation

## ◆ getOutput()

double Bandpass::getOutput | ( |  | ) |
| inline

Gets the output of the filter.

Same as the return value of the function "filter()".

The documentation for this class was generated from the following files:

- bandpass.h
- bandpass.cpp